@@ -1,4 +1,4 @@
-#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
 
 
 """ Command line options of Nuitka.
@@ -19,6 +19,7 @@ import sys
 from string import Formatter
 
 from nuitka.PythonFlavors import getPythonFlavorName
+from nuitka.PythonVersions import isPythonWithGil
 from nuitka.utils.CommandLineOptions import SUPPRESS_HELP, makeOptionsParser
 from nuitka.utils.FileOperations import getFileContentByLine
 from nuitka.utils.Utils import (
@@ -42,11 +43,34 @@ if _nuitka_binary_name == "__main__.py":
 is_nuitka_run = _nuitka_binary_name.lower().endswith("-run")
 
 if not is_nuitka_run:
-    usage_template = "usage: %s [--module] [--run] [options] main_module.py"
+    usage_template = (
+        "usage: %s [--mode=compilation_mode] [--run] [options] main_module.py"
+    )
 else:
-    usage_template = "usage: %s [options] main_module.py"
+    usage_template = "usage: %s [--mode=compilation_mode] [options] main_module.py"
 
 
+def _handleHelpModes():
+    result = False
+    for count, arg in enumerate(sys.argv[1:], start=1):
+        if arg == "--":
+            break
+        if arg in ("--help-all", "--help-plugin", "--help-plugins"):
+            result = True
+            sys.argv[count] = "--help"
+            break
+    return result
+
+
+plugin_help_mode = _handleHelpModes()
+
+
+if not plugin_help_mode:
+    usage_template += """\n
+    Note: For general plugin help (they often have their own
+    command line options too), consider the output of
+    '--help-plugins'."""
+
 parser = makeOptionsParser(usage=usage_template % _nuitka_binary_name)
 
 parser.add_option(
@@ -64,19 +88,40 @@ parser.add_option(
     action="store_true",
     dest="module_mode",
     default=False,
+    github_action=False,
     help="""\
 Create an importable binary extension module executable instead of a program. Defaults to off.""",
 )
 
+parser.add_option(
+    "--mode",
+    action="store",
+    dest="compilation_mode",
+    metavar="COMPILATION_MODE",
+    choices=("app", "onefile", "standalone", "accelerated", "module", "package", "dll"),
+    default=None,
+    github_action_default="app",
+    help="""\
+Mode in which to compile. Accelerated runs in your Python
+installation and depends on it. Standalone creates a folder
+with an executable contained to run it. Onefile creates a
+single executable to deploy. App is onefile except on macOS
+where it's not to be used. Module makes a module, and
+package includes also all sub-modules and sub-packages. Dll
+is currently under development and not for users yet.
+Default is 'accelerated'.""",
+)
+
 parser.add_option(
     "--standalone",
     action="store_true",
     dest="is_standalone",
     default=False,
+    github_action=False,
     help="""\
 Enable standalone mode for output. This allows you to transfer the created binary
 to other machines without it using an existing Python installation. This also
-means it will become big. It implies these option: "--follow-imports" and
+means it will become big. It implies these options: "--follow-imports" and
 "--python-flag=no_site". Defaults to off.""",
 )
 
@@ -94,7 +139,7 @@ parser.add_option(
     action="store_true",
     dest="is_onefile",
     default=False,
-    github_action_default=True,
+    github_action=False,
     help="""\
 On top of standalone mode, enable onefile mode. This means not a folder,
 but a compressed executable is created and used. Defaults to off.""",
@@ -121,7 +166,8 @@ Python executable. Currently supported: "-S" (alias "no_site"),
 "static_hashes" (do not use hash randomization), "no_warnings" (do not
 give Python run time warnings), "-O" (alias "no_asserts"), "no_docstrings"
 (do not use doc strings), "-u" (alias "unbuffered"), "isolated" (do not
-load outside code) and "-m" (package mode, compile as "package.__main__").
+load outside code), "-P" (alias "safe_path", do not used current directory
+in module search) and "-m" (package mode, compile as "package.__main__").
 Default empty.""",
 )
 
@@ -175,11 +221,12 @@ parser.add_option(
     dest="github_workflow_options",
     default=False,
     github_action=False,
-    help=SUPPRESS_HELP,
+    help=SUPPRESS_HELP,  # For use in GitHub Action only.
 )
 
 include_group = parser.add_option_group(
-    "Control the inclusion of modules and packages in result"
+    "Control the inclusion of modules and packages in result",
+    link="include-section",
 )
 
 include_group.add_option(
@@ -330,6 +377,22 @@ and being non-static it's removed. Use e.g. a string like
 static cache path, this will then not be removed.""",
 )
 
+onefile_group.add_option(
+    "--onefile-cache-mode",
+    action="store",
+    dest="onefile_cached_mode",
+    metavar="ONEFILE_CACHED_MODE",
+    choices=("auto", "cached", "temporary"),
+    default="auto",
+    help="""\
+This mode is inferred from your use of the spec. If it contains
+runtime dependent paths, "auto" resolves to "temporary" which
+will make sure to remove the unpacked binaries after execution,
+and cached will not remove it and see to reuse its contents
+during next execution for faster startup times.""",
+)
+
+
 onefile_group.add_option(
     "--onefile-child-grace-time",
     action="store",
@@ -364,6 +427,18 @@ with "nuitka-onefile-unpack" rather than a stream that only the onefile
 program itself unpacks. Default is off.""",
 )
 
+onefile_group.add_option(
+    "--onefile-no-dll",
+    action="store_true",
+    dest="onefile_no_dll",
+    default=False,
+    help="""\
+When creating the onefile, some platforms (Windows currently, if not
+using a cached location) default to using DLL rather than an executable
+for the Python code. This makes it use an executable in the unpacked
+files as well. Default is off.""",
+)
+
 del onefile_group
 
 data_group = parser.add_option_group("Data files")
@@ -383,13 +458,14 @@ This will only include non-DLL, non-extension modules, i.e. actual data
 files. After a ":" optionally a filename pattern can be given as
 well, selecting only matching files. Examples:
 "--include-package-data=package_name" (all files)
-"--include-package-data=package_name=*.txt" (only certain type)
-"--include-package-data=package_name=some_filename.dat (concrete file)
+"--include-package-data=package_name:*.txt" (only certain type)
+"--include-package-data=package_name:some_filename.dat (concrete file)
 Default empty.""",
 )
 
 data_group.add_option(
     "--include-data-files",
+    "--include-data-file",
     action="append",
     dest="data_files",
     metavar="DESC",
@@ -400,7 +476,7 @@ allowed forms. With '--include-data-files=/path/to/file/*.txt=folder_name/some.t
 will copy a single file and complain if it's multiple. With
 '--include-data-files=/path/to/files/*.txt=folder_name/' it will put
 all matching files into that folder. For recursive copy there is a
-form with 3 values that '--include-data-files=/path/to/scan=folder_name=**/*.txt'
+form with 3 values that '--include-data-files=/path/to/scan=folder_name/=**/*.txt'
 that will preserve directory structure. Default empty.""",
 )
 
@@ -433,6 +509,7 @@ whole directory simply use 'package_name'. Default empty.""",
 
 data_group.add_option(
     "--include-onefile-external-data",
+    "--include-data-files-external",
     action="append",
     dest="data_files_external",
     metavar="PATTERN",
@@ -440,8 +517,9 @@ data_group.add_option(
     help="""\
 Include the specified data file patterns outside of the onefile binary,
 rather than on the inside. Makes only sense in case of '--onefile'
-compilation. First files have to be specified as included somehow,
-then this refers to target paths. Default empty.""",
+compilation. First files have to be specified as included with other
+`--include-*data*` options, and then this refers to target paths
+inside the distribution. Default empty.""",
 )
 
 data_group.add_option(
@@ -485,6 +563,17 @@ not always happening. This of course only makes sense for packages that are
 included in the compilation. Default empty.""",
 )
 
+metadata_group.add_option(
+    "--list-distribution-metadata",
+    action="store_true",
+    dest="list_distribution_metadata",
+    default=False,
+    require_compiling=False,
+    help="""\
+Output the list of distributions and their details for all packages. Default not done.""",
+)
+
+
 del metadata_group
 
 dll_group = parser.add_option_group("DLL files")
@@ -513,6 +602,17 @@ dll_group.add_option(
 Output the DLLs found for a given package name. Default not done.""",
 )
 
+dll_group.add_option(
+    "--list-package-exe",
+    action="store",
+    dest="list_package_exe",
+    default="",
+    require_compiling=False,
+    help="""\
+Output the EXEs found for a given package name. Default not done.""",
+)
+
+
 del dll_group
 
 warnings_group = parser.add_option_group("Control the warnings to be given by Nuitka")
@@ -585,8 +685,9 @@ execute_group.add_option(
     dest="debugger",
     default=False,
     help="""\
-Execute inside a debugger, e.g. "gdb" or "lldb" to automatically get a stack trace.
-Defaults to off.""",
+Execute inside a debugger, e.g. "gdb" or "lldb" to automatically get a stack trace. The
+debugger is automatically chosen unless specified by name with the NUITKA_DEBUGGER_CHOICE
+environment variable. Defaults to off.""",
 )
 
 del execute_group
@@ -624,7 +725,7 @@ compilation_group.add_option(
     "--file-reference-choice",
     action="store",
     dest="file_reference_mode",
-    metavar="MODE",
+    metavar="FILE_MODE",
     choices=("original", "runtime", "frozen"),
     default=None,
     help="""\
@@ -643,7 +744,7 @@ compilation_group.add_option(
     "--module-name-choice",
     action="store",
     dest="module_name_mode",
-    metavar="MODE",
+    metavar="MODULE_NAME_MODE",
     choices=("original", "runtime"),
     default=None,
     help="""\
@@ -709,6 +810,18 @@ used to detect implicit imports.
 Defaults to off.""",
 )
 
+output_group.add_option(
+    "--no-pyi-stubs",
+    action="store_false",
+    dest="pyi_stubs",
+    default=True,
+    help="""\
+Do not use stubgen when creating a '.pyi' file for extension modules
+created by Nuitka. They expose your API, but stubgen may cause issues.
+Defaults to off.""",
+)
+
+
 del output_group
 
 deployment_group = parser.add_option_group("Deployment control")
@@ -764,6 +877,44 @@ Executing all self checks possible to find errors in Nuitka, do not use for
 production. Defaults to off.""",
 )
 
+debug_group.add_option(
+    "--no-debug-immortal-assumptions",
+    action="store_false",
+    dest="debug_immortal",
+    default=None,
+    help="""\
+Disable check normally done with "--debug". With Python3.12+ do not check known
+immortal object assumptions. Some C libraries corrupt them. Defaults to check
+being made if "--debug" is on.""",
+)
+
+debug_group.add_option(
+    "--debug-immortal-assumptions",
+    action="store_true",
+    dest="debug_immortal",
+    default=None,
+    help=SUPPRESS_HELP,
+)
+
+debug_group.add_option(
+    "--no-debug-c-warnings",
+    action="store_false",
+    dest="debug_c_warnings",
+    default=None,
+    help="""\
+Disable check normally done with "--debug". The C compilation may produce
+warnings, which it often does for some packages without these being issues,
+esp. for unused values.""",
+)
+
+debug_group.add_option(
+    "--debug-c-warnings",
+    action="store_true",
+    dest="debug_c_warnings",
+    default=None,
+    help=SUPPRESS_HELP,
+)
+
 debug_group.add_option(
     "--unstripped",
     "--unstriped",
@@ -785,17 +936,6 @@ debug_group.add_option(
 Enable vmprof based profiling of time spent. Not working currently. Defaults to off.""",
 )
 
-debug_group.add_option(
-    "--internal-graph",
-    action="store_true",
-    dest="internal_graph",
-    default=False,
-    github_action=False,
-    help="""\
-Create graph of optimization process internals, do not use for whole programs, but only
-for small test cases. Defaults to off.""",
-)
-
 debug_group.add_option(
     "--trace-execution",
     action="store_true",
@@ -806,20 +946,6 @@ Traced execution output, output the line of code before executing it.
 Defaults to off.""",
 )
 
-debug_group.add_option(
-    "--recompile-c-only",
-    action="store_true",
-    dest="recompile_c_only",
-    default=False,
-    github_action=False,
-    help="""\
-This is not incremental compilation, but for Nuitka development only. Takes
-existing files and simply compile them as C again. Allows compiling edited
-C files for quick debugging changes to the generated source, e.g. to see if
-code is passed by, values output, etc, Defaults to off. Depends on compiling
-Python source to determine which files it should look at.""",
-)
-
 debug_group.add_option(
     "--xml",
     action="store",
@@ -886,6 +1012,70 @@ off. Do not think you can use this directly.""",
 
 del debug_group
 
+
+development_group = parser.add_option_group("Nuitka Development features")
+
+
+development_group.add_option(
+    "--devel-missing-code-helpers",
+    action="store_true",
+    dest="report_missing_code_helpers",
+    default=False,
+    help="""\
+Report warnings for code helpers for types that were attempted, but don't
+exist. This helps to identify opportunities for improving optimization of
+generated code from type knowledge not used. Default False.""",
+)
+
+development_group.add_option(
+    "--devel-missing-trust",
+    action="store_true",
+    dest="report_missing_trust",
+    default=False,
+    help="""\
+Report warnings for imports that could be trusted, but currently are not. This
+is to identify opportunities for improving handling of hard modules, where this
+sometimes could allow more static optimization. Default False.""",
+)
+
+development_group.add_option(
+    "--devel-recompile-c-only",
+    action="store_true",
+    dest="recompile_c_only",
+    default=False,
+    github_action=False,
+    help="""\
+This is not incremental compilation, but for Nuitka development only. Takes
+existing files and simply compiles them as C again after doing the Python
+steps. Allows compiling edited C files for manual debugging changes to the
+generated source. Allows us to add printing, check and print values, but it
+is now what users would want. Depends on compiling Python source to
+determine which files it should look at.""",
+)
+
+development_group.add_option(
+    "--devel-internal-graph",
+    action="store_true",
+    dest="internal_graph",
+    default=False,
+    github_action=False,
+    help="""\
+Create graph of optimization process internals, do not use for whole programs, but only
+for small test cases. Defaults to off.""",
+)
+
+development_group.add_option(
+    "--devel-generate-ming64-header",
+    action="store_true",
+    dest="generate_mingw64_header",
+    default=False,
+    require_compiling=False,
+    github_action=False,
+    help=SUPPRESS_HELP,
+)
+
+del development_group
+
 # This is for testing framework, "coverage.py" hates to loose the process. And
 # we can use it to make sure it's not done unknowingly.
 parser.add_option(
@@ -925,7 +1115,7 @@ c_compiler_group.add_option(
     "--mingw64",
     action="store_true",
     dest="mingw64",
-    default=False,
+    default=None,
     help="""\
 Enforce the use of MinGW64 on Windows. Defaults to off unless MSYS2 with MinGW Python is used.""",
 )
@@ -952,8 +1142,9 @@ c_compiler_group.add_option(
     metavar="N",
     default=None,
     help="""\
-Specify the allowed number of parallel C compiler jobs. Defaults to the
-system CPU count.""",
+Specify the allowed number of parallel C compiler jobs. Negative values
+are system CPU minus the given value. Defaults to the full system CPU
+count unless low memory mode is activated, then it defaults to 1.""",
 )
 
 c_compiler_group.add_option(
@@ -1037,9 +1228,7 @@ caching_group.add_option(
     action="store_true",
     dest="disable_bytecode_cache",
     default=False,
-    help="""\
-Do not reuse dependency analysis results for modules, esp. from standard library,
-that are included as bytecode. Same as --disable-cache=bytecode.""",
+    help=SUPPRESS_HELP,
 )
 
 caching_group.add_option(
@@ -1047,23 +1236,18 @@ caching_group.add_option(
     action="store_true",
     dest="disable_ccache",
     default=False,
-    help="""\
-Do not attempt to use ccache (gcc, clang, etc.) or clcache (MSVC, clangcl).
-Same as --disable-cache=ccache.""",
+    help=SUPPRESS_HELP,
+)
+
+caching_group.add_option(
+    "--disable-dll-dependency-cache",
+    action="store_true",
+    dest="disable_dll_dependency_cache",
+    default=False,
+    help=SUPPRESS_HELP,
 )
 
 if isWin32Windows():
-    caching_group.add_option(
-        "--disable-dll-dependency-cache",
-        action="store_true",
-        dest="disable_dll_dependency_cache",
-        default=False,
-        help="""\
-Disable the dependency walker cache. Will result in much longer times to create
-the distribution folder, but might be used in case the cache is suspect to cause
-errors. Same as --disable-cache=dll-dependencies.""",
-    )
-
     caching_group.add_option(
         "--force-dll-dependency-cache-update",
         action="store_true",
@@ -1082,7 +1266,7 @@ del caching_group
 pgo_group = parser.add_option_group("PGO compilation choices")
 
 pgo_group.add_option(
-    "--pgo",
+    "--pgo-c",
     action="store_true",
     dest="is_c_pgo",
     default=False,
@@ -1098,7 +1282,7 @@ pgo_group.add_option(
     action="store_true",
     dest="is_python_pgo",
     default=False,
-    help=SUPPRESS_HELP,
+    help=SUPPRESS_HELP,  # Not yet ready
 )
 
 pgo_group.add_option(
@@ -1106,7 +1290,7 @@ pgo_group.add_option(
     action="store",
     dest="python_pgo_input",
     default=None,
-    help=SUPPRESS_HELP,
+    help=SUPPRESS_HELP,  # Not yet ready
 )
 
 pgo_group.add_option(
@@ -1115,7 +1299,7 @@ pgo_group.add_option(
     dest="python_pgo_policy_unused_module",
     choices=("include", "exclude", "bytecode"),
     default="include",
-    help=SUPPRESS_HELP,
+    help=SUPPRESS_HELP,  # Not yet ready
 )
 
 pgo_group.add_option(
@@ -1293,39 +1477,6 @@ del tracing_group
 
 os_group = parser.add_option_group("General OS controls")
 
-os_group.add_option(
-    "--disable-console",
-    "--macos-disable-console",
-    "--windows-disable-console",
-    action="store_true",
-    dest="disable_console",
-    default=None,
-    help=SUPPRESS_HELP,
-)
-
-os_group.add_option(
-    "--enable-console",
-    action="store_false",
-    dest="disable_console",
-    default=None,
-    help=SUPPRESS_HELP,
-)
-
-os_group.add_option(
-    "--windows-console-mode",
-    action="store",
-    dest="console_mode",
-    choices=("force", "disable", "attach"),
-    metavar="CONSOLE_MODE",
-    default=None,
-    help="""\
-Select console mode to use. Default mode is 'force' and creates a
-console window if not available, i.e. the program was started from one. With
-'disable' it doesn't create or use a console. With 'attach' an existing console
-will be used for outputs. Default is 'force'.
-""",
-)
-
 os_group.add_option(
     "--force-stdout-spec",
     "--windows-force-stdout-spec",
@@ -1360,11 +1511,19 @@ del os_group
 windows_group = parser.add_option_group("Windows specific controls")
 
 windows_group.add_option(
-    "--windows-dependency-tool",
+    "--windows-console-mode",
     action="store",
-    dest="dependency_tool",
+    dest="console_mode",
+    choices=("force", "disable", "attach", "hide"),
+    metavar="CONSOLE_MODE",
     default=None,
-    help=SUPPRESS_HELP,
+    help="""\
+Select console mode to use. Default mode is 'force' and creates a
+console window unless the program was started from one. With 'disable'
+it doesn't create or use a console at all. With 'attach' an existing
+console will be used for outputs. With 'hide' a newly spawned console
+will be hidden and an already existing console will behave like
+'force'. Default is 'force'.""",
 )
 
 windows_group.add_option(
@@ -1418,6 +1577,33 @@ Request Windows User Control, to enforce running from a few folders only, remote
 desktop access. (Windows only). Defaults to off.""",
 )
 
+windows_group.add_option(
+    "--disable-console",
+    "--macos-disable-console",
+    "--windows-disable-console",
+    action="store_true",
+    dest="disable_console",
+    default=None,
+    help=SUPPRESS_HELP,
+)
+
+windows_group.add_option(
+    "--enable-console",
+    action="store_false",
+    dest="disable_console",
+    default=None,
+    help=SUPPRESS_HELP,
+)
+
+windows_group.add_option(
+    "--windows-dependency-tool",
+    action="store",
+    dest="dependency_tool",
+    default=None,
+    help=SUPPRESS_HELP,
+)
+
+
 del windows_group
 
 
@@ -1427,7 +1613,8 @@ macos_group.add_option(
     "--macos-create-app-bundle",
     action="store_true",
     dest="macos_create_bundle",
-    default=False,
+    default=None,
+    github_action=False,
     help="""\
 When compiling for macOS, create a bundle rather than a plain binary
 application. This is the only way to unlock the disabling of console,
@@ -1485,9 +1672,9 @@ macos_group.add_option(
     "--macos-app-mode",
     action="store",
     dest="macos_app_mode",
-    metavar="MODE",
+    metavar="APP_MODE",
     choices=("gui", "background", "ui-element"),
-    default="gui",
+    default=None,
     help="""\
 Mode of application for the application bundle. When launching a Window, and appearing
 in Docker is desired, default value "gui" is a good fit. Without a Window ever, the
@@ -1496,12 +1683,22 @@ application is a "background" application. For UI elements that get to display l
 access to desktop when it does open a Window later.""",
 )
 
+macos_group.add_option(
+    "--macos-prohibit-multiple-instances",
+    action="store_true",
+    dest="macos_prohibit_multiple_instances",
+    default=False,
+    help="""\
+For application bundles, set the flag "LSMultipleInstancesProhibited" to prevent
+launching multiple instances of the application. Default is off.""",
+)
+
 macos_group.add_option(
     "--macos-sign-identity",
     action="store",
     dest="macos_sign_identity",
     metavar="MACOS_APP_VERSION",
-    default="ad-hoc",
+    default=None,
     help="""\
 When signing on macOS, by default an ad-hoc identify will be used, but with this
 option your get to specify another identity to use. The signing of code is now
@@ -1513,7 +1710,7 @@ macos_group.add_option(
     "--macos-sign-notarization",
     action="store_true",
     dest="macos_sign_notarization",
-    default=False,
+    default=None,
     help="""\
 When signing for notarization, using a proper TeamID identity from Apple, use
 the required runtime signing option, such that it can be accepted.""",
@@ -1543,8 +1740,8 @@ Request an entitlement for access to a macOS protected resources, e.g.
 requests access to the microphone and provides an informative text for
 the user, why that is needed. Before the colon, is an OS identifier for
 an access right, then the informative text. Legal values can be found on
-https://developer.apple.com/documentation/bundleresources/information_property_list/protected_resources and
-the option can be specified multiple times. Default empty.""",
+https://developer.apple.com/documentation/bundleresources/information_property_list/protected_resources
+and the option can be specified multiple times. Default empty.""",
 )
 
 
@@ -1736,6 +1933,23 @@ Default empty.""",
 
 del plugin_group
 
+target_group = parser.add_option_group("Cross compilation")
+
+
+target_group.add_option(
+    "--target",
+    action="store",
+    dest="target_desc",
+    metavar="TARGET_DESC",
+    default=None,
+    help="""\
+Cross compilation target. Highly experimental and in development, not
+supposed to work yet. We are working on '--target=wasi' and nothing
+else yet.""",
+)
+
+del target_group
+
 
 def _considerPluginOptions(logger):
     # Cyclic dependency on plugins during parsing of command line.
@@ -1745,7 +1959,9 @@ def _considerPluginOptions(logger):
         addUserPluginCommandLineOptions,
     )
 
-    addStandardPluginCommandLineOptions(parser=parser)
+    addStandardPluginCommandLineOptions(
+        parser=parser, plugin_help_mode=plugin_help_mode
+    )
 
     for arg in sys.argv[1:]:
         if arg.startswith(
@@ -1761,6 +1977,7 @@ def _considerPluginOptions(logger):
             addPluginCommandLineOptions(
                 parser=parser,
                 plugin_names=plugin_names.split(","),
+                plugin_help_mode=plugin_help_mode,
             )
 
         if arg.startswith("--user-plugin="):
@@ -1780,6 +1997,7 @@ run_time_variable_names = (
     "TIME",
     "PROGRAM",
     "PROGRAM_BASE",
+    "PROGRAM_DIR",
     "CACHE_DIR",
     "COMPANY",
     "PRODUCT",
@@ -1815,6 +2033,7 @@ def _expandProjectArg(arg, filename_arg, for_eval):
         "Version": getNuitkaVersion(),
         "Commercial": wrap(getCommercialVersion()),
         "MAIN_DIRECTORY": wrap(os.path.dirname(filename_arg) or "."),
+        "GIL": isPythonWithGil(),
     }
 
     if isLinux():
@@ -2066,7 +2285,7 @@ def parseOptions(logger):
         if arg.startswith(("--main=", "--script-name=")):
             filename_args.append(arg.split("=", 1)[1])
 
-        if arg == "--module":
+        if arg in ("--mode=module", "--mode=module", "--module=package"):
             module_mode = True
 
         if arg[0] != "-":
@@ -2125,12 +2344,26 @@ def runSpecialCommandsFromOptions(options):
         displayDLLs(options.list_package_dlls)
         sys.exit(0)
 
+    if options.list_package_exe:
+        from nuitka.tools.scanning.DisplayPackageDLLs import displayEXEs
+
+        displayEXEs(options.list_package_exe)
+        sys.exit(0)
+
     if options.list_package_data:
         from nuitka.tools.scanning.DisplayPackageData import displayPackageData
 
         displayPackageData(options.list_package_data)
         sys.exit(0)
 
+    if options.list_distribution_metadata:
+        from nuitka.tools.scanning.DisplayDistributions import (
+            displayDistributions,
+        )
+
+        displayDistributions()
+        sys.exit(0)
+
     if options.edit_module_code:
         from nuitka.tools.general.find_module.FindModuleCode import (
             editModuleCode,
@@ -2152,6 +2385,14 @@ def runSpecialCommandsFromOptions(options):
         )
         sys.exit(0)
 
+    if options.generate_mingw64_header:
+        from nuitka.tools.general.generate_header.GenerateHeader import (
+            generateHeader,
+        )
+
+        generateHeader()
+        sys.exit(0)
+
 
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
