@@ -1,4 +1,4 @@
-#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
 
 
 """ Python flavors specifics.
@@ -99,6 +99,9 @@ def isHomebrewPython():
     if not isMacOS():
         return False
 
+    if isGithubActionsPython():
+        return True
+
     candidate = os.path.join(
         getSystemPrefixPath(), "lib", "python" + python_version_str, "sitecustomize.py"
     )
@@ -113,6 +116,20 @@ def isHomebrewPython():
     return False
 
 
+def getHomebrewInstallPath():
+    assert isHomebrewPython()
+
+    candidate = getSystemPrefixPath()
+
+    while candidate != "/":
+        if os.path.isdir(os.path.join(candidate, "Cellar")):
+            return candidate
+
+        candidate = os.path.dirname(candidate)
+
+    sys.exit("Error, failed to locate homebrew installation path.")
+
+
 def isRyePython():
     if isMacOS():
         import sysconfig
@@ -126,6 +143,15 @@ def isRyePython():
     return False
 
 
+def isPythonBuildStandalonePython():
+    try:
+        import sysconfig
+
+        return sysconfig.get_config_var("PYTHON_BUILD_STANDALONE") == 1
+    except ImportError:
+        return False
+
+
 def isPyenvPython():
     if isWin32Windows():
         return False
@@ -163,6 +189,12 @@ def isUninstalledPython():
     if isDebianPackagePython():
         return False
 
+    if isSelfCompiledPythonUninstalled():
+        return True
+
+    if isPythonBuildStandalonePython():
+        return True
+
     if isStaticallyLinkedPython():
         return False
 
@@ -271,10 +303,14 @@ def isCPythonOfficialPackage():
     sys_prefix = getSystemPrefixPath()
 
     # For macOS however, it's very knowable.
-    if isMacOS() and isFilenameBelowPath(
-        path="/Library/Frameworks/Python.framework/Versions/", filename=sys_prefix
-    ):
-        return True
+    if isMacOS():
+        for candidate in (
+            "/Library/Frameworks/Python.framework/Versions/",
+            "/Library/Frameworks/PythonT.framework/Versions/",
+        ):
+
+            if isFilenameBelowPath(path=candidate, filename=sys_prefix):
+                return True
 
     # For Windows, we check registry.
     if isWin32Windows():
@@ -346,10 +382,14 @@ def getPythonFlavorName():
         return "Arch Python"
     elif isAlpinePackagePython():
         return "Alpine Python"
+    elif isGithubActionsPython():
+        return "GitHub Actions Python"
     elif isHomebrewPython():
         return "Homebrew Python"
     elif isRyePython():
         return "Rye Python"
+    elif isPythonBuildStandalonePython():
+        return "Python Build Standalone"
     elif isApplePython():
         return "Apple Python"
     elif isPyenvPython():
@@ -364,8 +404,6 @@ def getPythonFlavorName():
         return "CPython Official"
     elif isSelfCompiledPythonUninstalled():
         return "Self Compiled Uninstalled"
-    elif isGithubActionsPython():
-        return "GitHub Actions Python"
     elif isManyLinuxPython():
         return "Manylinux Python"
     else:
