@@ -1,14 +1,16 @@
-#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
 
 
 """ Interface to depends.exe on Windows.
 
-We use depends.exe to investigate needed DLLs of Python DLLs.
+We use "depends.exe" to investigate needed DLLs of Python DLLs.
 
 """
 
 import os
 
+# pylint: disable=I0021,import-error,redefined-builtin
+from nuitka.__past__ import WindowsError
 from nuitka.containers.OrderedSets import OrderedSet
 from nuitka.Options import assumeYesForDownloads
 from nuitka.Tracing import inclusion_logger
@@ -18,6 +20,7 @@ from nuitka.utils.FileOperations import (
     deleteFile,
     getExternalUsePath,
     getFileContentByLine,
+    getNormalizedPath,
     getWindowsLongPathName,
     isFilenameBelowPath,
     isFilesystemEncodable,
@@ -44,6 +47,7 @@ def getDependsExePath():
         url=depends_url,
         is_arch_specific=getArchitecture(),
         binary="depends.exe",
+        unzip=True,
         flatten=True,
         specificity="",  # Note: If there ever was an update, put version here.
         message="""\
@@ -51,6 +55,7 @@ Nuitka will make use of Dependency Walker (https://dependencywalker.com) tool
 to analyze the dependencies of Python extension modules.""",
         reject="Nuitka does not work in --standalone or --onefile on Windows without.",
         assume_yes_for_downloads=assumeYesForDownloads(),
+        download_ok=True,
     )
 
 
@@ -64,9 +69,10 @@ def _attemptToFindNotFoundDLL(dll_filename):
     if dll_filename in currently_loaded_dlls:
         return currently_loaded_dlls[dll_filename]
 
+    # Lets try the Windows system, spell-checker: ignore systemroot
     dll_filename = os.path.join(
         os.environ["SYSTEMROOT"],
-        "SysWOW64" if getArchitecture() == "x86_64" else "System32",
+        "System32" if getArchitecture() == "x86_64" else "SysWOW64",
         dll_filename,
     )
     dll_filename = os.path.normcase(dll_filename)
@@ -131,7 +137,13 @@ def _parseDependsExeOutput2(lines):
             continue
 
         dll_filename = os.path.abspath(dll_filename)
-        dll_filename = getWindowsLongPathName(dll_filename)
+
+        # Ignore errors trying to resolve the filename. Sometimes Chinese
+        # directory paths do not resolve to long filenames.
+        try:
+            dll_filename = getWindowsLongPathName(dll_filename)
+        except WindowsError:
+            pass
 
         dll_name = os.path.basename(dll_filename)
 
@@ -151,7 +163,7 @@ def _parseDependsExeOutput2(lines):
 
         assert os.path.isfile(dll_filename), (dll_filename, line)
 
-        result.add(os.path.normcase(os.path.abspath(dll_filename)))
+        result.add(getNormalizedPath(os.path.normcase(dll_filename)))
 
     return result
 
@@ -213,7 +225,8 @@ SxS
 
     if not os.path.exists(output_filename):
         inclusion_logger.sysexit(
-            "Error, 'depends.exe' failed to produce expected output."
+            "Error, 'depends.exe' failed to produce expected output for binary '%s'."
+            % binary_filename
         )
 
     # Opening the result under lock, so it is not getting locked by new processes.
