@@ -1,4 +1,4 @@
-#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
 
 
 """ Node meta classes.
@@ -41,11 +41,13 @@ def returnTrueShared():
     return True
 
 
-@staticmethod
-def returnFalseShared():
+def returnFalseSharedFunction():
     return False
 
 
+returnFalseShared = staticmethod(returnFalseSharedFunction)
+
+
 class NodeCheckMetaClass(ABCMeta):
     kinds = {}
 
@@ -138,7 +140,7 @@ class NodeCheckMetaClass(ABCMeta):
                 cls.isExpressionBuiltin = returnTrueShared
 
             # Add automatic checker "True" to the node class.
-            if getattr(cls, checker_method_name) is returnFalseShared.__func__:
+            if getattr(cls, checker_method_name) is returnFalseSharedFunction:
 
                 def checkKind(self):
                     return self.kind == kind
