@@ -1,4 +1,4 @@
-#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
 
 
 """ Standard plug-in to tell Nuitka about implicit imports.
@@ -22,10 +22,10 @@ from nuitka.utils.Utils import isMacOS, isWin32Windows
 
 class NuitkaPluginImplicitImports(NuitkaYamlPluginBase):
     plugin_name = "implicit-imports"
-
     plugin_desc = (
         "Provide implicit imports of package as per package configuration files."
     )
+    plugin_category = "core"
 
     def __init__(self):
         NuitkaYamlPluginBase.__init__(self)
@@ -87,7 +87,8 @@ class NuitkaPluginImplicitImports(NuitkaYamlPluginBase):
     def _resolveImplicitImportsConfig(self, full_name, dependency):
         if "(" in dependency:
             value = self.evaluateExpression(
-                full_name=full_name,
+                config_module_name=full_name,
+                module_name=full_name,
                 expression=dependency,
                 config_name="depends value",
                 extra_context=None,
@@ -121,8 +122,8 @@ class NuitkaPluginImplicitImports(NuitkaYamlPluginBase):
                     dependency = full_name.getChildNamed(dependency[1:]).asString()
                 elif full_name.getPackageName() is None:
                     # Not a package, potentially a naming conflict, when
-                    # compiling with "--module" something that matches a PyPI
-                    # name.
+                    # compiling with "--mode=module" something that matches a
+                    # PyPI name.
                     continue
                 else:
                     dependency = full_name.getSiblingNamed(dependency[1:]).asString()
@@ -359,7 +360,9 @@ class NuitkaPluginImplicitImports(NuitkaYamlPluginBase):
                     yield item
 
     def onModuleSourceCode(self, module_name, source_filename, source_code):
-        # TODO: Move the ones that would be possible to yaml config,
+        # TODO: Move the ones that would be possible to yaml config, or a
+        # separate plugin for lazy loaders.
+        # pylint: disable=too-many-branches,too-many-locals
 
         if module_name == "site":
             if source_code.startswith("def ") or source_code.startswith("class "):
@@ -416,9 +419,9 @@ __file__ = (__nuitka_binary_dir + '%ssite.py') if '__nuitka_binary_dir' in dict(
 
         if module_name == "huggingface_hub":
             # Special handling for huggingface that uses the source code variant
-            # of lazy module. spell-checker: ignore huggingface
+            # of lazy module. spell-checker: ignore huggingface,submod
             if (
-                "__getattr__, __dir__, __all__ = _attach(__name__, submodules=[], submod_attrs=_SUBMOD_ATTRS)"
+                "_attach(__name__, submodules=[], submod_attrs=_SUBMOD_ATTRS)"
                 in source_code
             ):
                 huggingface_hub_lazy_loader_info = self.queryRuntimeInformationSingle(
@@ -449,9 +452,17 @@ __file__ = (__nuitka_binary_dir + '%ssite.py') if '__nuitka_binary_dir' in dict(
                 )
 
                 pydantic_lazy_loader_info = {}
+                pydantic_lazy_submodules = []
+
                 for key, value in pydantic_info.items():
                     # Older pydantic had only a string for the attribute.
                     if type(value) is tuple:
+                        # Special case, __module__ means it's a sub-module
+                        if value == ("pydantic", "__module__"):
+                            pydantic_lazy_submodules.append(key)
+                            continue
+
+                        # Otherwise it's a long winded way of specifying a module name.
                         value = "".join(value).rstrip(".")
 
                     if value not in pydantic_lazy_loader_info:
@@ -460,10 +471,50 @@ __file__ = (__nuitka_binary_dir + '%ssite.py') if '__nuitka_binary_dir' in dict(
 
                 self._addLazyLoader(
                     module_name=module_name,
-                    submodules=(),
+                    submodules=pydantic_lazy_submodules,
                     submodule_attrs=pydantic_lazy_loader_info,
                 )
 
+        if module_name == "scipy":
+            # Scipy has its own lazy loading, spell-checker: ignore scipy
+            if "def __getattr__(" in source_code:
+                scipy_info = self.queryRuntimeInformationSingle(
+                    setup_codes="import scipy",
+                    value="scipy.submodules",
+                    info_name="scipy_lazy_loader",
+                )
+
+                self._addLazyLoader(
+                    module_name=module_name,
+                    submodules=scipy_info,
+                    submodule_attrs={},
+                )
+
+        if module_name == "toga":
+            # Toga has lazy loading in some versions.
+
+            if "def __getattr__(" in source_code:
+                toga_info = self.queryRuntimeInformationSingle(
+                    setup_codes="import toga",
+                    value="toga.toga_core_imports",
+                    info_name="toga_lazy_loader",
+                )
+
+                toga_submodule_attrs = {}
+
+                for attribute_name, sub_module_name in toga_info.items():
+                    if sub_module_name not in toga_submodule_attrs:
+                        toga_submodule_attrs[sub_module_name] = []
+                    toga_submodule_attrs[sub_module_name].append(attribute_name)
+
+                self._addLazyLoader(
+                    module_name=module_name,
+                    submodules=(),
+                    submodule_attrs=toga_submodule_attrs,
+                )
+
+                source_code = source_code.replace("= lazy_load()", " = %r" % toga_info)
+
         return source_code
 
     def _addLazyLoader(self, module_name, submodules, submodule_attrs):
@@ -674,6 +725,7 @@ According to Yaml 'overridden-environment-variables' configuration."""
     unworthy_modulename_patterns = (
         "tensorflow.*test",  # Not performance relevant.
         "tensorflow.**.test_util",  # Not performance relevant.
+        "google.protobuf.*_pb2",  #  Too large generated code
     )
 
     def decideCompilation(self, module_name):
