@@ -1,4 +1,4 @@
-#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
 
 
 """ Standard plug-in to make PyQt and PySide work well in standalone mode.
@@ -11,7 +11,8 @@ import os
 
 from nuitka.containers.OrderedSets import OrderedSet
 from nuitka.Options import (
-    isOnefileMode,
+    getWindowsIconExecutablePath,
+    getWindowsIconPaths,
     isStandaloneMode,
     shallCreateAppBundle,
 )
@@ -25,20 +26,18 @@ from nuitka.plugins.Plugins import (
 )
 from nuitka.PythonFlavors import isAnacondaPython
 from nuitka.PythonVersions import python_version
-from nuitka.utils.Distributions import (
-    getDistributionFromModuleName,
-    getDistributionInstallerName,
-    getDistributionName,
-)
-from nuitka.utils.FileOperations import getFileList, listDir
+from nuitka.utils.Distributions import getDistributionFromModuleName
+from nuitka.utils.FileOperations import getFileList, getNormalizedPath, listDir
 from nuitka.utils.ModuleNames import ModuleName
 from nuitka.utils.Utils import getArchitecture, isMacOS, isWin32Windows
 
 
 class NuitkaPluginQtBindingsPluginBase(NuitkaPluginBase):
-    # We are a bit detail rich and caching a bunch,
+    # Plenty of attributes, because it's storing many states.
     # pylint: disable=too-many-instance-attributes
 
+    plugin_category = "package-support,qt-binding"
+
     # Automatically suppress detectors for any other toolkit
     plugin_gui_toolkit = True
 
@@ -48,42 +47,65 @@ class NuitkaPluginQtBindingsPluginBase(NuitkaPluginBase):
     warned_about = set()
 
     def __init__(self, include_qt_plugins, noinclude_qt_plugins, no_qt_translations):
-        self.distribution = getDistributionFromModuleName(self.binding_name)
+        self.binding_package_name = ModuleName(self.binding_name)
 
-        if self.distribution is None:
-            self.sysexit(
-                "Error, failed to locate the %s installation." % self.binding_name
-            )
-
-        self.distribution_name = getDistributionName(self.distribution)
-
-        self.installer_name = getDistributionInstallerName(self.distribution_name)
+        self.include_qt_plugins = include_qt_plugins
+        self.noinclude_qt_plugins = noinclude_qt_plugins
+        self.no_qt_translations = no_qt_translations
 
         # Qt plugin directories found.
         self.qt_plugins_dirs = None
 
-        sensible_qt_plugins = self._getSensiblePlugins()
+        # Selected Qt plugins.
+        self.qt_plugins = None
 
-        include_qt_plugins = OrderedSet(
-            sum([value.split(",") for value in include_qt_plugins], [])
-        )
+        active_qt_plugin_name = getActiveQtPlugin()
 
-        # Useless, but nice for old option usage, where expanding it meant to repeat it.
-        if "sensible" in include_qt_plugins:
-            include_qt_plugins.remove("sensible")
-
-        self.qt_plugins = sensible_qt_plugins
-        self.qt_plugins.update(include_qt_plugins)
-
-        for noinclude_qt_plugin in noinclude_qt_plugins:
-            self.qt_plugins.discard(noinclude_qt_plugin)
-
-        self.no_qt_translations = no_qt_translations
+        if active_qt_plugin_name is not None:
+            self.sysexit(
+                "Error, conflicting plugin '%s', you can only have one enabled."
+                % active_qt_plugin_name
+            )
 
         self.web_engine_done_binaries = False
         self.web_engine_done_data = False
 
-        self.binding_package_name = ModuleName(self.binding_name)
+    def onCompilationStartChecks(self):
+        # Make sure, distribution location for this uses shortest name approach,
+        # we do not need to use the value, just want to make sure it is resolved
+        # properly and quickly.
+        _distribution = getDistributionFromModuleName(
+            self.binding_package_name, prefer_shorter_distribution_name=True
+        )
+
+        if self.locateModule(self.binding_package_name) is None:
+            self.sysexit(
+                "Error, failed to locate the '%s' installation." % self.binding_name
+            )
+
+        sensible_qt_plugins = self._getSensiblePlugins()
+
+        self.include_qt_plugins = OrderedSet(
+            sum([value.split(",") for value in self.include_qt_plugins], [])
+        )
+
+        # Useless, but nice for old option usage, where expanding it meant to repeat it.
+        if "sensible" in self.include_qt_plugins:
+            self.include_qt_plugins.remove("sensible")
+
+        for include_qt_plugin in self.include_qt_plugins:
+            if include_qt_plugin not in ("qml", "all") and not self.hasPluginFamily(
+                include_qt_plugin
+            ):
+                self.sysexit(
+                    "Error, there is no Qt plugin family '%s'." % include_qt_plugin
+                )
+
+        self.qt_plugins = sensible_qt_plugins
+        self.qt_plugins.update(self.include_qt_plugins)
+
+        for noinclude_qt_plugin in self.noinclude_qt_plugins:
+            self.qt_plugins.discard(noinclude_qt_plugin)
 
         # Allow to specify none.
         if self.qt_plugins == set(["none"]):
@@ -95,14 +117,6 @@ class NuitkaPluginQtBindingsPluginBase(NuitkaPluginBase):
         # Also lets have consistency in naming.
         assert self.plugin_name in getQtPluginNames()
 
-        active_qt_plugin_name = getActiveQtPlugin()
-
-        if active_qt_plugin_name is not None:
-            self.sysexit(
-                "Error, conflicting plugin '%s', you can only have one enabled."
-                % active_qt_plugin_name
-            )
-
     @classmethod
     def addPluginCommandLineOptions(cls, group):
         group.add_option(
@@ -194,7 +208,7 @@ of files that you may not want to be included.""",
 
     @staticmethod
     def _getWebEngineTargetDir():
-        """Where does the Qt bindings package expect the web process executable."""
+        """Where to put the web process executable."""
         return "."
 
     def _getSensiblePlugins(self):
@@ -233,10 +247,21 @@ of files that you may not want to be included.""",
 
         return "all" in selected or plugin_name in selected
 
+    def _applyBindingCondaLibraryPath(self, sub_path):
+        return self._applyBindingName(
+            "os.path.join(os.path.dirname(%(binding_name)s.__file__), '..', '..', '..', 'Library', "
+            + sub_path
+            + ")"
+        )
+
+    def _applyBindingName(self, template):
+        return template % {
+            "binding_name": self.binding_name,
+            "qt_major_version": self.binding_name[-1],
+        }
+
     def _getQtInformation(self):
         # This is generic, and therefore needs to apply this to a lot of strings.
-        def applyBindingName(template):
-            return template % {"binding_name": self.binding_name}
 
         def getLocationQueryCode(path_name):
             if self.binding_name == "PyQt6":
@@ -251,7 +276,7 @@ of files that you may not want to be included.""",
                 "path_name": path_name,
             }
 
-        setup_codes = applyBindingName(
+        setup_codes = self._applyBindingName(
             r"""
 import os
 import %(binding_name)s.QtCore
@@ -259,30 +284,34 @@ import %(binding_name)s.QtCore
         )
 
         info = self.queryRuntimeInformationMultiple(
-            info_name=applyBindingName("%(binding_name)s_info"),
+            info_name=self._applyBindingName("%(binding_name)s_info"),
             setup_codes=setup_codes,
             values=(
                 (
                     "library_paths",
-                    applyBindingName(
+                    self._applyBindingName(
                         "%(binding_name)s.QtCore.QCoreApplication.libraryPaths()"
                     ),
                 ),
                 (
                     "guess_path1",
-                    applyBindingName(
+                    self._applyBindingName(
                         "os.path.join(os.path.dirname(%(binding_name)s.__file__), 'plugins')"
                     ),
                 ),
                 (
                     "guess_path2",
-                    applyBindingName(
-                        "os.path.join(os.path.dirname(%(binding_name)s.__file__), '..', '..', '..', 'Library', 'plugins')"
+                    self._applyBindingCondaLibraryPath("'plugins'"),
+                ),
+                (
+                    "guess_path3",
+                    self._applyBindingCondaLibraryPath(
+                        "'lib', 'qt%(qt_major_version)s', 'plugins'"
                     ),
                 ),
                 (
                     "version",
-                    applyBindingName(
+                    self._applyBindingName(
                         "%(binding_name)s.__version_info__"
                         if "PySide" in self.binding_name
                         else "%(binding_name)s.QtCore.PYQT_VERSION_STR"
@@ -290,16 +319,40 @@ import %(binding_name)s.QtCore
                 ),
                 (
                     "nuitka_patch_level",
-                    applyBindingName(
+                    self._applyBindingName(
                         "getattr(%(binding_name)s, '_nuitka_patch_level', 0)"
                     ),
                 ),
-                ("translations_path", getLocationQueryCode("TranslationsPath")),
+                (
+                    "translations_path",
+                    getLocationQueryCode("TranslationsPath"),
+                ),
+                (
+                    "translations_path_guess",
+                    self._applyBindingCondaLibraryPath(
+                        "'share', 'qt%(qt_major_version)s', 'translations'"
+                    ),
+                ),
                 (
                     "library_executables_path",
                     getLocationQueryCode("LibraryExecutablesPath"),
                 ),
-                ("data_path", getLocationQueryCode("DataPath")),
+                (
+                    "library_executables_path_guess",
+                    self._applyBindingCondaLibraryPath(
+                        "'lib', 'qt%(qt_major_version)s'"
+                    ),
+                ),
+                (
+                    "data_path",
+                    getLocationQueryCode("DataPath"),
+                ),
+                (
+                    "qt_resources_path_guess",
+                    self._applyBindingCondaLibraryPath(
+                        "'share', 'qt%(qt_major_version)s', 'resources'"
+                    ),
+                ),
             ),
         )
 
@@ -320,7 +373,15 @@ import %(binding_name)s.QtCore
 
     def _getTranslationsPath(self):
         """Get the path to the Qt translations."""
-        return self._getQtInformation().translations_path
+        translation_path = self._getQtInformation().translations_path
+
+        if not os.path.exists(translation_path):
+            translation_path = self._getQtInformation().translations_path_guess
+
+        if not os.path.exists(translation_path):
+            self.sysexit("Error, failed to detect QtWebEngine translation path")
+
+        return translation_path
 
     def _getWebEngineResourcesPath(self):
         """Get the path to the Qt web engine resources."""
@@ -330,11 +391,31 @@ import %(binding_name)s.QtCore
                 "lib/QtWebEngineCore.framework/Resources",
             )
         else:
-            return os.path.join(self._getQtInformation().data_path, "resources")
+            resources_path = os.path.join(
+                self._getQtInformation().data_path, "resources"
+            )
+
+            if not os.path.exists(resources_path):
+                resources_path = self._getQtInformation().qt_resources_path_guess
+
+            if not os.path.exists(resources_path):
+                self.sysexit("Error, failed to detect QtWebEngine resources path")
+
+            return resources_path
 
     def _getWebEngineExecutablePath(self):
         """Get the path to QtWebEngine binary."""
-        return os.path.normpath(self._getQtInformation().library_executables_path)
+        library_executables_path = self._getQtInformation().library_executables_path
+
+        if not os.path.exists(library_executables_path):
+            library_executables_path = (
+                self._getQtInformation().library_executables_path_guess
+            )
+
+        if not os.path.exists(library_executables_path):
+            self.sysexit("Error, failed to detect QtWebEngine library path")
+
+        return getNormalizedPath(library_executables_path)
 
     def getQtPluginDirs(self):
         if self.qt_plugins_dirs is not None:
@@ -346,13 +427,14 @@ import %(binding_name)s.QtCore
 
         if not self.qt_plugins_dirs and os.path.exists(qt_info.guess_path1):
             self.qt_plugins_dirs.append(qt_info.guess_path1)
-
         if not self.qt_plugins_dirs and os.path.exists(qt_info.guess_path2):
             self.qt_plugins_dirs.append(qt_info.guess_path2)
+        if not self.qt_plugins_dirs and os.path.exists(qt_info.guess_path3):
+            self.qt_plugins_dirs.append(qt_info.guess_path3)
 
         # Avoid duplicates.
         self.qt_plugins_dirs = [
-            os.path.normpath(dirname) for dirname in self.qt_plugins_dirs
+            getNormalizedPath(dirname) for dirname in self.qt_plugins_dirs
         ]
         self.qt_plugins_dirs = tuple(sorted(set(self.qt_plugins_dirs)))
 
@@ -364,12 +446,12 @@ import %(binding_name)s.QtCore
     def _getQtBinDirs(self):
         for plugin_dir in self.getQtPluginDirs():
             if "PyQt" in self.binding_name:
-                qt_bin_dir = os.path.normpath(os.path.join(plugin_dir, "..", "bin"))
+                qt_bin_dir = getNormalizedPath(os.path.join(plugin_dir, "..", "bin"))
 
                 if os.path.isdir(qt_bin_dir):
                     yield qt_bin_dir
             else:
-                qt_bin_dir = os.path.normpath(os.path.join(plugin_dir, ".."))
+                qt_bin_dir = getNormalizedPath(os.path.join(plugin_dir, ".."))
 
                 yield qt_bin_dir
 
@@ -381,7 +463,7 @@ import %(binding_name)s.QtCore
 
     def _getQmlDirectory(self):
         for plugin_dir in self.getQtPluginDirs():
-            qml_plugin_dir = os.path.normpath(os.path.join(plugin_dir, "..", "qml"))
+            qml_plugin_dir = getNormalizedPath(os.path.join(plugin_dir, "..", "qml"))
 
             if os.path.exists(qml_plugin_dir):
                 return qml_plugin_dir
@@ -601,15 +683,67 @@ import %(binding_name)s.QtCore
         For Qt we need to set the library path to the distribution folder
         we are running from. The code is immediately run after the code
         and therefore makes sure it's updated properly.
-        """
 
-        # Only in standalone mode, this will be needed.
-        if not isStandaloneMode():
-            return
+        Also, for QApplication we try and load icons automatically.
+        TODO: Currently only for Windows, but we could add icons from macOS too
+        """
 
         full_name = module.getFullName()
 
-        if full_name == "%s.QtCore" % self.binding_name:
+        # We do this for PySide6 only.
+        if (
+            full_name == "%s" % self.binding_name
+            and self.binding_name == "PySide6"
+            and (getWindowsIconPaths() or getWindowsIconExecutablePath())
+        ):
+            # TODO: Ideally we would know the icons count and not be confused by
+            # resources the user may have added themselves.
+
+            # spell-checker: ignore Pixmap
+            code = """\
+import sys
+import %(binding_name)s.QtWidgets
+orig_QApplication = %(binding_name)s.QtWidgets.QApplication
+
+from %(binding_name)s.QtGui import QIcon, QPixmap, QImage
+
+class OurQApplication(orig_QApplication):
+    def __init__(self, *args, **kwargs):
+        orig_QApplication.__init__(self, *args, **kwargs)
+        main_filename = sys.argv[0]
+
+        import ctypes
+        ctypes.windll.shell32.ExtractIconExW.restype = ctypes.wintypes.HICON
+        ctypes.windll.shell32.ExtractIconExW.argtypes = (ctypes.wintypes.LPCWSTR, ctypes.c_int, ctypes.POINTER(ctypes.wintypes.HICON), ctypes.POINTER(ctypes.wintypes.HICON), ctypes.c_uint)
+        icon_count = ctypes.windll.shell32.ExtractIconExW(main_filename, -1, None, None, 0)
+
+        assert icon_count > 0
+
+        small_icon = ctypes.wintypes.HICON()
+        large_icon = ctypes.wintypes.HICON()
+
+        icons = []
+        for icon_index in range(icon_count):
+            res = ctypes.windll.shell32.ExtractIconExW(main_filename, icon_index, ctypes.byref(small_icon), ctypes.byref(large_icon), 1)
+
+            icons.append(small_icon.value)
+            icons.append(large_icon.value)
+
+        icon = QIcon()
+        for icon_handle in icons:
+            icon.addPixmap(QPixmap.fromImage(QImage.fromHICON(icon_handle)))
+
+        self.setWindowIcon(icon)
+
+%(binding_name)s.QtWidgets.QApplication = OurQApplication
+""" % {
+                "binding_name": self.binding_name
+            }
+
+            yield (code, "Loading Qt application icon from Windows resources.")
+
+        # Only in standalone mode, this will be needed.
+        if full_name == "%s.QtCore" % self.binding_name and isStandaloneMode():
             code = """\
 from __future__ import absolute_import
 
@@ -687,14 +821,58 @@ if not path.startswith(__nuitka_binary_dir):
             )
 
         # We need to set these variables, to force the layout
-        # spell-checker: ignore QTWEBENGINEPROCESS_PATH,QTWEBENGINE_DISABLE_SANDBOX
+        # spell-checker: ignore QTWEBENGINEPROCESS_PATH,QTWEBENGINE_DISABLE_SANDBOX,
+        # spell-checker: ignore QTWEBENGINE_RESOURCES_PATH
 
-        if self.isQtWebEngineModule(full_name) and self._isUsingMacOSFrameworks():
+        if self.isQtWebEngineModule(full_name):
             code = r"""
 import os
+os.environ["QTWEBENGINE_LOCALES_PATH"] = os.path.join(
+    __nuitka_binary_dir,
+    %(web_engine_locales_path)r,
+    "qtwebengine_locales"
+)
+""" % {
+                "web_engine_locales_path": self._getTranslationsTargetDir()
+            }
+
+            yield (
+                code,
+                "Setting WebEngine translations path'.",
+            )
+
+            if isWin32Windows():
+                # TODO: Need to do it for DLL mode for sure, but we should do it
+                # for all platforms.
+                code = r"""
+os.environ["QTWEBENGINEPROCESS_PATH"] = os.path.normpath(
+    os.path.join(
+        __nuitka_binary_dir,
+        %(web_engine_process_path)r
+    )
+)
+os.environ["QTWEBENGINE_RESOURCES_PATH"] = os.path.normpath(
+    os.path.join(
+        __nuitka_binary_dir,
+        %(web_engine_resources_path)r
+    )
+)
+
+                """ % {
+                    "web_engine_process_path": "QtWebEngineProcess.exe",
+                    "web_engine_resources_path": self._getWebEngineResourcesTargetDir(),
+                }
+
+                yield (
+                    code,
+                    "Setting Qt WebEngine binary path'.",
+                )
+
+            if self._isUsingMacOSFrameworks():
+                code = r"""
 os.environ["QTWEBENGINEPROCESS_PATH"] = os.path.join(
     __nuitka_binary_dir,
-    "%(web_engine_process_path)s"
+    %(web_engine_process_path)r
 )
 os.environ["QTWEBENGINE_LOCALES_PATH"] = os.path.join(
     __nuitka_binary_dir,
@@ -702,15 +880,15 @@ os.environ["QTWEBENGINE_LOCALES_PATH"] = os.path.join(
 )
 os.environ["QTWEBENGINE_DISABLE_SANDBOX"]="1"
 """ % {
-                "web_engine_process_path": """\
+                    "web_engine_process_path": """\
 %s/Qt/lib/QtWebEngineCore.framework/Helpers/QtWebEngineProcess.app/Contents/MacOS/QtWebEngineProcess"""
-                % self.binding_name
-            }
+                    % self.binding_name
+                }
 
-            yield (
-                code,
-                "Setting WebEngine binary and translation path'.",
-            )
+                yield (
+                    code,
+                    "Setting Qt WebEngine binary path'.",
+                )
 
     def _handleWebEngineDataFiles(self):
         # Do it only once
@@ -744,12 +922,6 @@ Prefix = .
         for filename in getFileList(resources_dir):
             filename_relative = os.path.relpath(filename, resources_dir)
 
-            if not isOnefileMode():
-                yield self.makeIncludedAppBundleResourceFile(
-                    source_path=filename,
-                    dest_path=filename_relative,
-                    reason="Qt WebEngine resources",
-                )
             yield self.makeIncludedDataFile(
                 source_path=filename,
                 dest_path=filename_relative,
@@ -770,6 +942,11 @@ Prefix = .
         if self.binding_name in ("PySide6", "PyQt6"):
             used_frameworks += ["QtOpenGL", "QtDBus"]
 
+        # Newer PySide6 needs even more.
+        if self.binding_name == "PySide6" and self._getBindingVersion() >= (6, 8, 0):
+            used_frameworks.append("QtQmlMeta")
+            used_frameworks.append("QtQmlWorkerScript")
+
         for used_framework in used_frameworks:
             yield self.makeIncludedAppBundleFramework(
                 source_path=os.path.join(self._getQtInformation().data_path, "lib"),
@@ -861,11 +1038,14 @@ Prefix = .
 
         qt_web_engine_dir = self._getWebEngineExecutablePath()
 
+        if not os.path.isdir(qt_web_engine_dir):
+            assert False, qt_web_engine_dir
+
         for filename, filename_relative in listDir(qt_web_engine_dir):
             if filename_relative.startswith("QtWebEngineProcess"):
                 yield self.makeExeEntryPoint(
                     source_path=filename,
-                    dest_path=os.path.normpath(
+                    dest_path=getNormalizedPath(
                         os.path.join(self._getWebEngineTargetDir(), filename_relative)
                     ),
                     module_name=full_name,
@@ -1086,6 +1266,9 @@ behavior with the uncompiled code."""
                     "Not included due to its plugin not being active, but a Qt plugin is.",
                 )
 
+            if module_name == self.binding_name:
+                return (True, "Included to allow post load workaround code.")
+
     def onModuleCompleteSet(self, module_set):
         self.onModuleCompleteSetGUI(
             module_set=module_set, plugin_binding_name=self.binding_name
@@ -1163,7 +1346,7 @@ to compiled functions, etc. may not be working.""",
 
                     # That is how it is built for Anaconda.
                     if "_h_env" in path_parts:
-                        return os.path.normpath(
+                        return getNormalizedPath(
                             os.path.join(
                                 conda_prefix,
                                 *path_parts[path_parts.index("_h_env") + 1 :]
@@ -1374,13 +1557,8 @@ class NuitkaPluginPySide6Plugins(NuitkaPluginQtBindingsPluginBase):
 
     binding_name = "PySide6"
 
-    def __init__(self, include_qt_plugins, noinclude_qt_plugins, no_qt_translations):
-        NuitkaPluginQtBindingsPluginBase.__init__(
-            self,
-            include_qt_plugins=include_qt_plugins,
-            noinclude_qt_plugins=noinclude_qt_plugins,
-            no_qt_translations=no_qt_translations,
-        )
+    def onCompilationStartChecks(self):
+        NuitkaPluginQtBindingsPluginBase.onCompilationStartChecks(self)
 
         if self._getBindingVersion() < (6, 5, 0):
             self.warning(
@@ -1429,11 +1607,20 @@ Support for PyQt6 is not perfect, e.g. Qt threading does not work, so prefer PyS
         )
 
 
+class NuitkaPluginDetectorPyQt6Plugins(NuitkaPluginBase):
+    detector_for = NuitkaPluginPyQt6Plugins
+
+    def onModuleDiscovered(self, module):
+        if module.getFullName() == NuitkaPluginPyQt6Plugins.binding_name + ".QtCore":
+            self.warnUnusedPlugin("Standalone mode support and Qt plugins.")
+
+
 class NuitkaPluginNoQt(NuitkaPluginBase):
     """This is a plugins for suppression of all Qt binding plugins."""
 
     plugin_name = "no-qt"
-    plugin_desc = "Disable all Qt bindings for standalone mode."
+    plugin_desc = "Disable inclusion of all Qt bindings."
+    plugin_category = "package-support"
 
     warned_about = set()
 
@@ -1442,24 +1629,24 @@ class NuitkaPluginNoQt(NuitkaPluginBase):
     ):
         top_package_name = module_name.getTopLevelPackageName()
 
-        if isStandaloneMode():
-            if top_package_name in getQtBindingNames():
-                if top_package_name not in self.warned_about:
-                    self.info(
-                        """\
+        if top_package_name in getQtBindingNames():
+            if isStandaloneMode() and top_package_name not in self.warned_about:
+                self.info(
+                    """\
 Unwanted import of '%(unwanted)s' that is forbidden encountered, preventing \
 its use. As a result an "ImportError" might be given at run time. Uninstall \
 it for full compatible behavior with the uncompiled code to debug it."""
-                        % {
-                            "unwanted": top_package_name,
-                        }
-                    )
+                    % {
+                        "unwanted": top_package_name,
+                    }
+                )
 
-                    self.warned_about.add(top_package_name)
+                self.warned_about.add(top_package_name)
 
-                return (False, "Not included due to all Qt bindings disallowed.")
+            return (False, "Not included due to all Qt bindings disallowed.")
 
     def getEvaluationConditionControlTags(self):
+        # spell-checker: ignore noqt
         return {"use_noqt": True}
 
 
